require 'csv'

class TrainingSchedulerParser
  # Week,Monday,Tuesday,Wednesday,Thursday,Friday,Saturday,Sunday,
  PARSED = CSV.parse(
    <<-RUBY
        1,off,30 min run,off,25 min run,easy walk,off,3 miles,Jan 2-8
        2,off,30 min run,off,30 min run,easy walk,off,4 miles,Jan9-15
        3,off,30 min run,off,30 min run,easy walk,off,5 miles,Jan 16-22
        4,off,30 min run,off,30 min run,easy walk,off,2.5 miles,Jan 23-29
        5,off,30 min run,off,30 min run,easy walk,off,6.5 miles,Jan 30-Feb 5
        6,off,30 min run,off,30 min run,easy walk,off,3 miles with MM,Feb 6-12
        7,off,30 min run,off,30 min run,easy walk,off,8 miles,Feb 13-19
        8,off,30 min run,off,30 min run,easy walk,off,3 miles with MM,Feb 20-26
        9,off,30 min run,off,30 min run,easy walk,off,9.5 miles,Feb 27-Mar 5
        10,off,30 min run,off,30 min run,easy walk,off,4 miles,Mar 6-12
        11,off,30 min run,off,30 min run,easy walk,off,11 miles,Mar 13-19
        12,off,30 min run,off,30 min run,easy walk,off,4 miles with MM,Mar 20-26
        13,off,30 min run,off,30 min run,easy walk,off,12.5 miles,Mar 27-Apr 2
        14,off,30 min run,off,30 min run,easy walk,off,4 miles with MM,Apr 3-9
        15,off,30 min run,off,30 min run,easy walk,off,14 miles,Apr 10-16
        16,off,30 min run,off,30 min run,easy walk,off,5 miles,Apr 17-23
        17,off,30 min run,off,30 min run,easy walk,Half Marathon Race,off,Apr 24-30
        18,off,30 min run,off,30 min run,easy walk,off,5 miles,May1-7
        19,off,30 min run,off,30 min run,easy walk,off,6-8 miles,May 8-14
    RUBY
  )

  DAYS_OF_THE_WEEK = %w( Monday Tuesday Wednesday Thursday Friday Saturday Sunday )

  COMMAND_MAP = {
    'today' => 'get_day_data',
    'week' => 'current_week'
  }

  attr_reader :input,
              :current_day

  def initialize(input)
    @input = input
    current_time = Time.now.utc - 6 * 3600
    @current_day = current_time.to_date
  end

  def perform
    self.send COMMAND_MAP[input].to_sym
  end

  def current_week
    DAYS_OF_THE_WEEK.zip(get_week_data[1..7]).flatten.join(', ')
  end

  def get_week_data
    PARSED.select{|r| r.first.strip.to_i == current_day.cweek}.flatten
  end

  def get_day_data
    get_week_data[current_day.cwday]
  end
end
